Test website

This page contains mostly all embeded content we have in this test website.

## Audio tag

## Video tag

Your browser does not support the video tag.

## Instagram embed from Feb. 2024

> View this post on Instagram

> A post shared by Wikipedia (@wikipedia)

## Facebook video embed from Feb. 2024

## Facebook post embed from Feb. 2024

## Twitter post embed from Feb. 2024

> Each year, millions of people around the world celebrate the Lunar New Year on the first new moon of their calendar. 🧵⬇️ (1/4) pic.twitter.com/62LnDy5sLt

> — Wikipedia (@Wikipedia) February 9, 2024

## Twitter video embed from Feb. 2024

> These are the 10 most-popular English Wikipedia articles of 2023.
> What about you, did the free encyclopedia help you discover anything new this year?
> 🔊 Evan Schaeffer, CC BY 4.0 pic.twitter.com/FBgZDSp5Jk

> — Wikipedia (@Wikipedia) December 23, 2023

## Vimeo video

## Youtube video

## Twitch iframe

## Twitch JS

## TikTok

> @elienv_ Répondre à @lordv_ Possible de trouver la page philosophie à partir de n’importe quel article ? #tiktokacademie #wikipedia #challenge ♬ Time Time - Trei Degete

## Dailymotion

## Spotify

## Soundcloud

IAM · Je danse le Mia

## MediaElement.js player

## Broken inline CSS

CSS not broken, background image displayed
CSS broken, background image displayed as well

## Broken CSS file

CSS not broken, background image displayed
CSS broken, background image displayed as well

## Chinese encoding

Not present here, makes no sense.

## Bad encoding

Not present here, it becomes valid at every file save in a text editor.

## URL encoding test(s)

Image with non-encoded chars in name with non-encoded special chars in link - an image should be displayed below

Image with non-encoded chars in name and already encoded special chars - an image should be displayed below

Image with non-encoded chars in name and a mix of non-encoded and already encoded special chars - an image should be displayed below

Image with many weird characters - an image should be displayed below

Image with UTF-8 characters - an image should be displayed below

Hostname with UTF-8 chars and simple image - an image should be displayed below

Hostname with UTF-8 chars and image with UTF-8 chars - an image should be displayed below

Hostname with UTF-8 chars and query parameter 1 - an image should be displayed below with a 1 in the right

Hostname with UTF-8 chars and query parameter 2 - an image should be displayed below with a 2 in the right